=========
Changelog
=========

Version 0.0.5
=============

- Bug fix with conf.py

Version 0.0.4
=============

- Bug fix with requirements.txt

Version 0.0.3
=============

- Proper docs

Version 0.0.2
=============

- Deleted classifiers

Version 0.0.1
=============

- Main backtesting functionality works
- Docs added




